GoogleCloudApigeeV1AccessLoggingConfig

Struct GoogleCloudApigeeV1AccessLoggingConfig 

pub struct GoogleCloudApigeeV1AccessLoggingConfig {
    pub enabled: Option<bool>,
    pub filter: Option<String>,
}
Access logging configuration enables customers to ship the access logs from the tenant projects to their own project’s cloud logging. The feature is at the instance level ad disabled by default. It can be enabled during CreateInstance or UpdateInstance.

This type is not used in any activity, and only used as part of another schema.

Fields

enabled: Option<bool>

Optional. Boolean flag that specifies whether the customer access log feature is enabled.

filter: Option<String>

Optional. Ship the access log entries that match the status_code defined in the filter. The status_code is the only expected/supported filter field. (Ex: status_code) The filter will parse it to the Common Expression Language semantics for expression evaluation to build the filter condition. (Ex: “filter”: status_code >= 200 && status_code < 300 )