pub struct GoogleCloudApigeeV1ApiDebugSession {
pub api_proxy_revision_id: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub environment_id: Option<String>,
pub id: Option<String>,
}Expand description
Session carries the debug session id and its creation time.
This type is not used in any activity, and only used as part of another schema.
Fields
api_proxy_revision_id: Option<String>The revision ID of the deployed API proxy.
create_time: Option<DateTime<Utc>>The first transaction creation timestamp in millisecond, recorded by UAP.
environment_id: Option<String>The environment ID of the deployed API proxy.
id: Option<String>The debug session ID.