pub struct GoogleCloudApigeeV1AsyncQueryResult {
pub expires: Option<String>,
pub self_: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
expires: Option<String>Query result will be unaccessable after this time.
self_: Option<String>Self link of the query results. Example: /organizations/myorg/environments/myenv/queries/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd/result or following format if query is running at host level: /organizations/myorg/hostQueries/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd/result