GoogleCloudApigeeV1ControlPlaneAccess

Struct GoogleCloudApigeeV1ControlPlaneAccess 

pub struct GoogleCloudApigeeV1ControlPlaneAccess {
    pub analytics_publisher_identities: Option<Vec<String>>,
    pub name: Option<String>,
    pub synchronizer_identities: Option<Vec<String>>,
}
ControlPlaneAccess is the request body and response body of UpdateControlPlaneAccess. and the response body of GetControlPlaneAccess. The input identities contains an array of service accounts to grant access to the respective control plane resource, with each service account specified using the following format: serviceAccount:service-account-name. The service-account-name is formatted like an email address. For example: my-control-plane-service_account@my_project_id.iam.gserviceaccount.com You might specify multiple service accounts, for example, if you have multiple environments and wish to assign a unique service account to each one.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

analytics_publisher_identities: Option<Vec<String>>

Optional. Array of service accounts authorized to publish analytics data to the control plane (for the Message Processor component).

name: Option<String>

Identifier. The resource name of the ControlPlaneAccess. Format: “organizations/{org}/controlPlaneAccess”

synchronizer_identities: Option<Vec<String>>

Optional. Array of service accounts to grant access to control plane resources (for the Synchronizer component). The service accounts must have Apigee Synchronizer Manager role. See also Create service accounts.