pub struct GoogleCloudApigeeV1DeleteCustomReportResponse {
pub message: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- reports delete organizations (response)
Fields
message: Option<String>The response contains only a message field.