pub struct GoogleCloudApigeeV1DeploymentConfig {
pub attributes: Option<HashMap<String, String>>,
pub base_path: Option<String>,
pub deployment_groups: Option<Vec<String>>,
pub endpoints: Option<HashMap<String, String>>,
pub location: Option<String>,
pub name: Option<String>,
pub proxy_uid: Option<String>,
pub service_account: Option<String>,
pub uid: Option<String>,
}Expand description
NEXT ID: 11
This type is not used in any activity, and only used as part of another schema.
Fields
attributes: Option<HashMap<String, String>>Additional key-value metadata for the deployment.
base_path: Option<String>Base path where the application will be hosted. Defaults to “/”.
deployment_groups: Option<Vec<String>>The list of deployment groups in which this proxy should be deployed. Not currently populated for shared flows.
endpoints: Option<HashMap<String, String>>A mapping from basepaths to proxy endpoint names in this proxy. Not populated for shared flows.
location: Option<String>Location of the API proxy bundle as a URI.
name: Option<String>Name of the API or shared flow revision to be deployed in the following format: organizations/{org}/apis/{api}/revisions/{rev} or organizations/{org}/sharedflows/{sharedflow}/revisions/{rev}
proxy_uid: Option<String>Unique ID of the API proxy revision.
service_account: Option<String>The service account identity associated with this deployment. If non-empty, will be in the following format: projects/-/serviceAccounts/{account_email}
uid: Option<String>Unique ID. The ID will only change if the deployment is deleted and recreated.