pub struct GoogleCloudApigeeV1DeveloperBalanceWallet {
pub balance: Option<GoogleTypeMoney>,
pub last_credit_time: Option<i64>,
}Expand description
Wallet used to manage an account balance for a particular currency.
This type is not used in any activity, and only used as part of another schema.
Fields
balance: Option<GoogleTypeMoney>Current remaining balance of the developer for a particular currency.
last_credit_time: Option<i64>Output only. Time at which the developer last added credit to the account in milliseconds since epoch.