pub struct GoogleCloudApigeeV1EnvironmentConfigClientIPResolutionConfig {
pub header_index_algorithm: Option<GoogleCloudApigeeV1EnvironmentConfigClientIPResolutionConfigHeaderIndexAlgorithm>,
}Expand description
Configuration for resolving the client ip.
This type is not used in any activity, and only used as part of another schema.
Fields
header_index_algorithm: Option<GoogleCloudApigeeV1EnvironmentConfigClientIPResolutionConfigHeaderIndexAlgorithm>Resolves the client ip based on a custom header.