pub struct GoogleCloudApigeeV1EnvironmentConfigClientIPResolutionConfigHeaderIndexAlgorithm {
pub ip_header_index: Option<i32>,
pub ip_header_name: Option<String>,
}Expand description
Resolves the client ip based on a custom header.
This type is not used in any activity, and only used as part of another schema.
Fields
ip_header_index: Option<i32>The index of the ip in the header. (By default, value is 0 if missing)
ip_header_name: Option<String>The name of the header to extract the client ip from.