pub struct GoogleCloudApigeeV1GraphQLOperationGroup {
pub operation_config_type: Option<String>,
pub operation_configs: Option<Vec<GoogleCloudApigeeV1GraphQLOperationConfig>>,
}Expand description
List of graphQL operation configuration details associated with Apigee API proxies or remote services. Remote services are non-Apigee proxies, such as Istio-Envoy.
This type is not used in any activity, and only used as part of another schema.
Fields
operation_config_type: Option<String>Flag that specifies whether the configuration is for Apigee API proxy or a remote service. Valid values include proxy or remoteservice. Defaults to proxy. Set to proxy when Apigee API proxies are associated with the API product. Set to remoteservice when non-Apigee proxies like Istio-Envoy are associated with the API product.
operation_configs: Option<Vec<GoogleCloudApigeeV1GraphQLOperationConfig>>Required. List of operation configurations for either Apigee API proxies or other remote services that are associated with this API product.