pub struct GoogleCloudApigeeV1GrpcOperationConfig {
pub api_source: Option<String>,
pub attributes: Option<Vec<GoogleCloudApigeeV1Attribute>>,
pub methods: Option<Vec<String>>,
pub quota: Option<GoogleCloudApigeeV1Quota>,
pub service: Option<String>,
}Expand description
Binds the resources in a proxy or remote service with the gRPC operation and its associated quota enforcement.
This type is not used in any activity, and only used as part of another schema.
Fields
api_source: Option<String>Required. Name of the API proxy with which the gRPC operation and quota are associated.
attributes: Option<Vec<GoogleCloudApigeeV1Attribute>>Custom attributes associated with the operation.
methods: Option<Vec<String>>List of unqualified gRPC method names for the proxy to which quota will be applied. If this field is empty, the Quota will apply to all operations on the gRPC service defined on the proxy. Example: Given a proxy that is configured to serve com.petstore.PetService, the methods com.petstore.PetService.ListPets and com.petstore.PetService.GetPet would be specified here as simply [“ListPets”, “GetPet”].
quota: Option<GoogleCloudApigeeV1Quota>Quota parameters to be enforced for the methods and API source combination. If none are specified, quota enforcement will not be done.
service: Option<String>Required. gRPC Service name associated to be associated with the API proxy, on which quota rules can be applied upon.