pub struct GoogleCloudApigeeV1InstanceDeploymentStatus {
pub deployed_revisions: Option<Vec<GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRevision>>,
pub deployed_routes: Option<Vec<GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRoute>>,
pub instance: Option<String>,
}Expand description
The status of a deployment as reported by a single instance.
This type is not used in any activity, and only used as part of another schema.
Fields
deployed_revisions: Option<Vec<GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRevision>>Revisions currently deployed in MPs.
deployed_routes: Option<Vec<GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRoute>>Current routes deployed in the ingress routing table. A route which is missing will appear in missing_routes.
instance: Option<String>ID of the instance reporting the status.