pub struct GoogleCloudApigeeV1InstanceDeploymentStatusDeployedRoute {
pub basepath: Option<String>,
pub envgroup: Option<String>,
pub environment: Option<String>,
pub percentage: Option<i32>,
}Expand description
Route deployed in the ingress routing table.
This type is not used in any activity, and only used as part of another schema.
Fields
basepath: Option<String>Base path in the routing table.
envgroup: Option<String>Environment group where this route is installed.
environment: Option<String>Destination environment. This will be empty if the route is not yet reported.
percentage: Option<i32>Percentage of ingress replicas reporting this route.