pub struct GoogleCloudApigeeV1KeyAliasReference {
pub alias_id: Option<String>,
pub reference: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
alias_id: Option<String>Alias ID. Must exist in the keystore referred to by the reference.
reference: Option<String>Reference name in the following format: organizations/{org}/environments/{env}/references/{reference}