pub struct GoogleCloudApigeeV1ListDebugSessionsResponse {
pub next_page_token: Option<String>,
pub sessions: Option<Vec<GoogleCloudApigeeV1Session>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>Page token that you can include in a ListDebugSessionsRequest to retrieve the next page. If omitted, no subsequent pages exist.
sessions: Option<Vec<GoogleCloudApigeeV1Session>>Session info that includes debug session ID and the first transaction creation timestamp.