pub struct GoogleCloudApigeeV1ListSecurityMonitoringConditionsResponse {
pub next_page_token: Option<String>,
pub security_monitoring_conditions: Option<Vec<GoogleCloudApigeeV1SecurityMonitoringCondition>>,
}Expand description
Response for ListSecurityMonitoringConditions.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.
security_monitoring_conditions: Option<Vec<GoogleCloudApigeeV1SecurityMonitoringCondition>>List of security monitoring conditions in the organization.