pub struct GoogleCloudApigeeV1MaintenanceUpdatePolicy {
pub maintenance_channel: Option<String>,
pub maintenance_windows: Option<Vec<GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow>>,
}Expand description
MaintenanceUpdatePolicy specifies the preferred window to perform maintenance on the instance (day of the week and time of day).
This type is not used in any activity, and only used as part of another schema.
Fields
maintenance_channel: Option<String>Optional. Maintenance channel to specify relative scheduling for maintenance.
maintenance_windows: Option<Vec<GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow>>Optional. Preferred windows to perform maintenance. Currently limited to 1.