pub struct GoogleCloudApigeeV1Metadata {
pub errors: Option<Vec<String>>,
pub notices: Option<Vec<String>>,
}Expand description
Encapsulates additional information about query execution.
This type is not used in any activity, and only used as part of another schema.
Fields
errors: Option<Vec<String>>List of error messages as strings.
notices: Option<Vec<String>>List of additional information such as data source, if result was truncated. For example: "notices": [ "Source:Postgres", "PG Host:uappg0rw.e2e.apigeeks.net", "query served by:4b64601e-40de-4eb1-bfb9-eeee7ac929ed", "Table used: edge.api.uapgroup2.agg_api" ]