pub struct GoogleCloudApigeeV1MoveApiProxyRequest {
pub space: Option<String>,
}Expand description
Moves an API Proxy to a different Space.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- apis move organizations (request)
Fields
space: Option<String>Optional. Resource ID of the space to move the proxy to. If unspecified, the proxy will be moved to the organization level.