pub struct GoogleCloudApigeeV1MoveSharedFlowRequest {
pub space: Option<String>,
}Expand description
Moves a Shared Flow to a different space.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- sharedflows move organizations (request)
Fields
space: Option<String>Optional. Resource ID of the space to move the shared flow to. If unspecified, the shared flow will be moved to the organization level.