pub struct GoogleCloudApigeeV1NodeConfig {
pub current_aggregate_node_count: Option<i64>,
pub max_node_count: Option<i64>,
pub min_node_count: Option<i64>,
}Expand description
NodeConfig for setting the min/max number of nodes associated with the environment.
This type is not used in any activity, and only used as part of another schema.
Fields
current_aggregate_node_count: Option<i64>Output only. The current total number of gateway nodes that each environment currently has across all instances.
max_node_count: Option<i64>Optional. The maximum total number of gateway nodes that the is reserved for all instances that has the specified environment. If not specified, the default is determined by the recommended maximum number of nodes for that gateway.
min_node_count: Option<i64>Optional. The minimum total number of gateway nodes that the is reserved for all instances that has the specified environment. If not specified, the default is determined by the recommended minimum number of nodes for that gateway.