pub struct GoogleCloudApigeeV1PodStatus {
pub app_version: Option<String>,
pub deployment_status: Option<String>,
pub deployment_status_time: Option<i64>,
pub deployment_time: Option<i64>,
pub pod_name: Option<String>,
pub pod_status: Option<String>,
pub pod_status_time: Option<i64>,
pub status_code: Option<String>,
pub status_code_details: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
app_version: Option<String>Version of the application running in the pod.
deployment_status: Option<String>Status of the deployment. Valid values include: - deployed: Successful. - error : Failed. - pending : Pod has not yet reported on the deployment.
deployment_status_time: Option<i64>Time the deployment status was reported in milliseconds since epoch.
deployment_time: Option<i64>Time the proxy was deployed in milliseconds since epoch.
pod_name: Option<String>Name of the pod which is reporting the status.
pod_status: Option<String>Overall status of the pod (not this specific deployment). Valid values include: - active: Up to date. - stale : Recently out of date. Pods that have not reported status in a long time are excluded from the output.
pod_status_time: Option<i64>Time the pod status was reported in milliseconds since epoch.
status_code: Option<String>Code associated with the deployment status.
status_code_details: Option<String>Human-readable message associated with the status code.