pub struct GoogleCloudApigeeV1ProfileConfig {
pub categories: Option<Vec<GoogleCloudApigeeV1ProfileConfigCategory>>,
}Expand description
ProfileConfig defines a set of categories and policies which will be used to compute security score.
This type is not used in any activity, and only used as part of another schema.
Fields
categories: Option<Vec<GoogleCloudApigeeV1ProfileConfigCategory>>List of categories of profile config.