pub struct GoogleCloudApigeeV1QueryMetric {
pub alias: Option<String>,
pub function: Option<String>,
pub name: Option<String>,
pub operator: Option<String>,
pub value: Option<String>,
}Expand description
More info about Metric: https://docs.apigee.com/api-platform/analytics/analytics-reference#metrics
This type is not used in any activity, and only used as part of another schema.
Fields
alias: Option<String>Alias for the metric. Alias will be used to replace metric name in query results.
function: Option<String>Aggregation function: avg, min, max, or sum.
name: Option<String>Required. Metric name.
operator: Option<String>One of +, -, /, %, *.
value: Option<String>Operand value should be provided when operator is set.