pub struct GoogleCloudApigeeV1ReferenceConfig {
pub name: Option<String>,
pub resource_name: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Name of the reference in the following format: organizations/{org}/environments/{env}/references/{reference}
resource_name: Option<String>Name of the referenced resource in the following format: organizations/{org}/environments/{env}/keystores/{keystore} Only references to keystore resources are supported.