GoogleCloudApigeeV1RuntimeConfig

Struct GoogleCloudApigeeV1RuntimeConfig 

pub struct GoogleCloudApigeeV1RuntimeConfig {
    pub analytics_bucket: Option<String>,
    pub name: Option<String>,
    pub tenant_project_id: Option<String>,
    pub trace_bucket: Option<String>,
}
Runtime configuration for the organization. Response for GetRuntimeConfig.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

analytics_bucket: Option<String>

Cloud Storage bucket used for uploading Analytics records.

name: Option<String>

Name of the resource in the following format: organizations/{org}/runtimeConfig.

tenant_project_id: Option<String>

Output only. Tenant project ID associated with the Apigee organization. The tenant project is used to host Google-managed resources that are dedicated to this Apigee organization. Clients have limited access to resources within the tenant project used to support Apigee runtime instances. Access to the tenant project is managed using SetSyncAuthorization. It can be empty if the tenant project hasn’t been created yet.

trace_bucket: Option<String>

Cloud Storage bucket used for uploading Trace records.