pub struct GoogleCloudApigeeV1SecurityActionHttpHeader {
pub name: Option<String>,
pub value: Option<String>,
}Expand description
An HTTP header.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>The header name to be sent to the target.
value: Option<String>The header value to be sent to the target.