pub struct GoogleCloudApigeeV1SecurityReportQueryMetric {
pub aggregation_function: Option<String>,
pub alias: Option<String>,
pub name: Option<String>,
pub operator: Option<String>,
pub value: Option<String>,
}Expand description
Metric of the Query
This type is not used in any activity, and only used as part of another schema.
Fields
aggregation_function: Option<String>Aggregation function: avg, min, max, or sum.
alias: Option<String>Alias for the metric. Alias will be used to replace metric name in query results.
name: Option<String>Required. Metric name.
operator: Option<String>One of +, -, /, %, *.
value: Option<String>Operand value should be provided when operator is set.