pub struct GoogleCloudApigeeV1Session {
pub id: Option<String>,
pub timestamp_ms: Option<i64>,
}Expand description
Session carries the debug session id and its creation time.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>The debug session ID.
timestamp_ms: Option<i64>The first transaction creation timestamp in millisecond, recorded by UAP.