pub struct GoogleCloudApigeeV1SharedFlow {
pub latest_revision_id: Option<String>,
pub meta_data: Option<GoogleCloudApigeeV1EntityMetadata>,
pub name: Option<String>,
pub revision: Option<Vec<String>>,
pub space: Option<String>,
}Expand description
The metadata describing a shared flow
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- sharedflows delete organizations (response)
- sharedflows get organizations (response)
- sharedflows move organizations (response)
Fields
latest_revision_id: Option<String>The id of the most recently created revision for this shared flow.
meta_data: Option<GoogleCloudApigeeV1EntityMetadata>Metadata describing the shared flow.
name: Option<String>The ID of the shared flow.
revision: Option<Vec<String>>A list of revisions of this shared flow.
space: Option<String>Optional. The ID of the space associated with this shared flow. Any IAM policies applied to the space will control access to this shared flow. To learn how Spaces can be used to manage resources, read the Apigee Spaces Overview.