pub struct GoogleCloudApigeeV1Stats {
pub environments: Option<Vec<GoogleCloudApigeeV1StatsEnvironmentStats>>,
pub hosts: Option<Vec<GoogleCloudApigeeV1StatsHostStats>>,
pub meta_data: Option<GoogleCloudApigeeV1Metadata>,
}Expand description
Encapsulates a stats response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- environments stats get organizations (response)
- host stats get organizations (response)
Fields
environments: Option<Vec<GoogleCloudApigeeV1StatsEnvironmentStats>>List of query results on the environment level.
hosts: Option<Vec<GoogleCloudApigeeV1StatsHostStats>>List of query results grouped by host.
meta_data: Option<GoogleCloudApigeeV1Metadata>Metadata information.