pub struct GoogleCloudApigeeV1StatsEnvironmentStats {
pub dimensions: Option<Vec<GoogleCloudApigeeV1DimensionMetric>>,
pub metrics: Option<Vec<GoogleCloudApigeeV1Metric>>,
pub name: Option<String>,
}Expand description
Encapsulates the environment wrapper: "environments": [ { "metrics": [ { "name": "sum(message_count)", "values": [ "2.52056245E8" ] } ], "name": "prod" } ]
This type is not used in any activity, and only used as part of another schema.
Fields
dimensions: Option<Vec<GoogleCloudApigeeV1DimensionMetric>>List of metrics grouped under dimensions.
metrics: Option<Vec<GoogleCloudApigeeV1Metric>>In the final response, only one of the following fields will be present based on the dimensions provided. If no dimensions are provided, then only top-level metrics is provided. If dimensions are included, then there will be a top-level dimensions field under environments which will contain metrics values and the dimension name. Example: "environments": [ { "dimensions": [ { "metrics": [ { "name": "sum(message_count)", "values": [ "2.14049521E8" ] } ], "name": "nit_proxy" } ], "name": "prod" } ] or "environments": [ { "metrics": [ { "name": "sum(message_count)", "values": [ "2.19026331E8" ] } ], "name": "prod" } ] List of metric values.
name: Option<String>Name of the environment.