pub struct GoogleCloudApigeeV1TargetServerConfig {
pub enabled: Option<bool>,
pub host: Option<String>,
pub name: Option<String>,
pub port: Option<i32>,
pub protocol: Option<String>,
pub tls_info: Option<GoogleCloudApigeeV1TlsInfoConfig>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
enabled: Option<bool>Whether the target server is enabled. An empty/omitted value for this field should be interpreted as true.
host: Option<String>Host name of the target server.
name: Option<String>Target server revision name in the following format: organizations/{org}/environments/{env}/targetservers/{targetserver}/revisions/{rev}
port: Option<i32>Port number for the target server.
protocol: Option<String>The protocol used by this target server.
tls_info: Option<GoogleCloudApigeeV1TlsInfoConfig>TLS settings for the target server.