pub struct GoogleCloudApigeeV1TraceSamplingConfig {
pub sampler: Option<String>,
pub sampling_rate: Option<f32>,
}Expand description
TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.
This type is not used in any activity, and only used as part of another schema.
Fields
sampler: Option<String>Sampler of distributed tracing. OFF is the default value.
sampling_rate: Option<f32>Field sampling rate. This value is only applicable when using the PROBABILITY sampler. The supported values are > 0 and <= 0.5.