pub struct GoogleRpcPreconditionFailureViolation {
pub description: Option<String>,
pub subject: Option<String>,
pub type_: Option<String>,
}Expand description
A message type used to describe a single precondition failure.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>A description of how the precondition failed. Developers can use this description to understand how to fix the failure. For example: “Terms of service not accepted”.
subject: Option<String>The subject, relative to the type, that failed. For example, “google.com/cloud” relative to the “TOS” type would indicate which terms of service is being referenced.
type_: Option<String>The type of PreconditionFailure. We recommend using a service-specific enum type to define the supported precondition violation subjects. For example, “TOS” for “Terms of Service violation”.