pub struct GoogleCloudApigeeV1ApimServiceExtensionExtension {
pub fail_open: Option<bool>,
pub hostname: Option<String>,
pub match_condition: Option<String>,
pub name: Option<String>,
pub supported_events: Option<Vec<String>>,
}Expand description
Extension configuration for Apigee extension processor service extension.
This type is not used in any activity, and only used as part of another schema.
Fields
fail_open: Option<bool>Optional. Whether this request should fail open.
hostname: Option<String>Required. One of the hostnames of Apigee EnvGroup where the proxy is deployed. This hostname (i.e FDQN) will be used to route traffic from the specified forwarding rule to the environment in Apigee X instance where the proxy is deployed for handling extension traffic. Format: ^([a-zA-Z0-9. _-])+$
match_condition: Option<String>Optional. Match Condition for CEL expression. Refer to https://cloud.google.com/service-extensions/docs/cel-matcher-language-reference for more details.
name: Option<String>Required. Name of the LbTrafficExtension resource. The name must conform with RFC-1034, is restricted to lower-cased letters, numbers and hyphens, and can have a maximum length of 63 characters. Additionally, the first character must be a letter and the last a letter or a number.
supported_events: Option<Vec<String>>Optional. Supported events for the Service Extension. If not specified, all events are supported.