pub struct GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArrayResource {
pub name: Option<String>,
pub type_: Option<String>,
}Expand description
Resource for which we are computing security assessment.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Required. Name of this resource. For an Apigee API Proxy, this should be the id of the API proxy. For an API Hub Deployment, this should be the id of the deployment.
type_: Option<String>Required. Type of this resource.