pub struct GoogleCloudApigeeV1ProvisionOrganizationRequest {
pub analytics_region: Option<String>,
pub authorized_network: Option<String>,
pub disable_vpc_peering: Option<bool>,
pub runtime_location: Option<String>,
}Expand description
Request for ProvisionOrganization.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- provision organization projects (request)
Fields
analytics_region: Option<String>Primary Cloud Platform region for analytics data storage. For valid values, see Create an organization. Defaults to us-west1.
Compute Engine network used for Service Networking to be peered with Apigee runtime instances. See Getting started with the Service Networking API. Apigee also supports shared VPC (that is, the host network project is not the same as the one that is peering with Apigee). See Shared VPC overview. To use a shared VPC network, use the following format: projects/{host-project-id}/{region}/networks/{network-name}. For example: projects/my-sharedvpc-host/global/networks/mynetwork
disable_vpc_peering: Option<bool>Optional. Flag that specifies whether the VPC Peering through Private Google Access should be disabled between the consumer network and Apigee. Required if an authorizedNetwork on the consumer project is not provided, in which case the flag should be set to true. The value must be set before the creation of any Apigee runtime instance and can be updated only when there are no runtime instances. Note: Apigee will be deprecating the vpc peering model that requires you to provide ‘authorizedNetwork’, by making the non-peering model as the default way of provisioning Apigee organization in future. So, this will be a temporary flag to enable the transition. Not supported for Apigee hybrid.
runtime_location: Option<String>Cloud Platform location for the runtime instance. Defaults to zone us-west1-a. If a region is provided, EVAL organizations will use the region for automatically selecting a zone for the runtime instance.