pub struct GoogleCloudApigeeV1QueryTimeSeriesStatsResponse {
pub columns: Option<Vec<String>>,
pub next_page_token: Option<String>,
pub values: Option<Vec<GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence>>,
}Expand description
Represents security stats result as a collection of time series sequences.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
columns: Option<Vec<String>>Column names corresponding to the same order as the inner values in the stats field.
next_page_token: Option<String>Next page token.
values: Option<Vec<GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence>>Results of the query returned as a JSON array.