pub struct GoogleCloudApigeeV1RoutingRule {
pub basepath: Option<String>,
pub deployment_group: Option<String>,
pub env_group_revision: Option<i64>,
pub environment: Option<String>,
pub other_targets: Option<Vec<String>>,
pub receiver: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
basepath: Option<String>URI path prefix used to route to the specified environment. May contain one or more wildcards. For example, path segments consisting of a single * character will match any string.
deployment_group: Option<String>Name of a deployment group in an environment bound to the environment group in the following format: organizations/{org}/environment/{env}/deploymentGroups/{group} Only one of environment or deployment_group will be set.
env_group_revision: Option<i64>The env group config revision_id when this rule was added or last updated. This value is set when the rule is created and will only update if the the environment_id changes. It is used to determine if the runtime is up to date with respect to this rule. This field is omitted from the IngressConfig unless the GetDeployedIngressConfig API is called with view=FULL.
environment: Option<String>Name of an environment bound to the environment group in the following format: organizations/{org}/environments/{env}. Only one of environment or deployment_group will be set.
other_targets: Option<Vec<String>>Conflicting targets, which will be resource names specifying either deployment groups or environments.
receiver: Option<String>The resource name of the proxy revision that is receiving this basepath in the following format: organizations/{org}/apis/{api}/revisions/{rev}. This field is omitted from the IngressConfig unless the GetDeployedIngressConfig API is called with view=FULL.
update_time: Option<DateTime<Utc>>The unix timestamp when this rule was updated. This is updated whenever env_group_revision is updated. This field is omitted from the IngressConfig unless the GetDeployedIngressConfig API is called with view=FULL.